@@ -18,9 +18,15 @@ from meshagent.tools import ToolContext, Toolkit
 from livekit.agents import Agent, AgentSession, ChatContext
 from livekit.agents.llm import RawFunctionTool, ToolError, function_tool
 
-from openai import AsyncOpenAI
+from meshagent.openai.proxy import get_client
 from meshagent.agents import AgentChatContext
-from livekit.agents import BackgroundAudioPlayer, AudioConfig, BuiltinAudioClip
+from livekit.agents import (
+    BackgroundAudioPlayer,
+    AudioConfig,
+    BuiltinAudioClip,
+    RoomInputOptions,
+    RoomOutputOptions,
+)
 
 from livekit.plugins import openai, silero
 # from livekit.plugins.turn_detector.multilingual import MultilingualModel
@@ -32,7 +38,6 @@ from typing import Any
 
 
 from livekit import rtc
-from livekit.agents import RunContext
 
 from typing import Optional
 
@@ -270,13 +275,6 @@ class VoiceBot(SingleRoomAgent):
         )
 
     async def create_agent(self, *, context: ToolContext, session: AgentSession):
-        @function_tool
-        async def say(context: RunContext, text: str):
-            "says something out loud to the user"
-            logger.info(f"saying: {text}")
-            session.say(text)
-            return "success"
-
         ctx = ChatContext()
 
         initial_context = await self.init_chat_context()
@@ -287,7 +285,7 @@ class VoiceBot(SingleRoomAgent):
             chat_ctx=ctx,
             instructions="\n".join(self.rules),
             allow_interruptions=True,
-            tools=[*await self.make_function_tools(context=context), say],
+            tools=[*await self.make_function_tools(context=context)],
         )
 
         # agent = Agent(
@@ -305,23 +303,14 @@ class VoiceBot(SingleRoomAgent):
         return AgentChatContext()
 
     def create_session(self, *, context: ToolContext) -> AgentSession:
-        token: str = context.room.protocol.token
-        url: str = context.room.room_url
-
-        room_proxy_url = f"{url}/v1"
-
-        oaiclient = AsyncOpenAI(
-            api_key=token,
-            base_url=room_proxy_url,
-            default_headers={"Meshagent-Session": context.room.session_id},
-        )
+        oaiclient = get_client(room=self.room)
 
         session = AgentSession(
             max_tool_steps=50,
             allow_interruptions=True,
             vad=silero.VAD.load(),
             stt=openai.STT(client=oaiclient),
-            tts=openai.TTS(client=oaiclient, voice="echo"),
+            tts=openai.TTS(client=oaiclient),
             llm=openai.LLM(client=oaiclient),
             # turn_detection=MultilingualModel(),
         )
@@ -355,7 +344,18 @@ class VoiceBot(SingleRoomAgent):
                 room=connection.livekit_room, agent_session=session
             )
 
-            await session.start(agent=agent, room=connection.livekit_room)
+            await session.start(
+                agent=agent,
+                room=connection.livekit_room,
+                room_input_options=RoomInputOptions(
+                    text_enabled=False,
+                    delete_room_on_close=False,
+                ),
+                room_output_options=RoomOutputOptions(
+                    transcription_enabled=True,
+                    audio_enabled=True,
+                ),
+            )
 
             if self.auto_greet_prompt is not None:
                 session.generate_reply(user_input=self.auto_greet_prompt)
